@@ -1,5 +1,5 @@
 import re
-from typing import Union, Dict
+from typing import Union, Dict, Sequence
 
 import js2py
 import js2py.internals.simplex
@@ -43,29 +43,30 @@ def product_details_tech_spec(selector: parsel.Selector, *fields) -> str:
     return table(selector, "//table[@id='productDetails_techSpec_section_1']", *fields)
 
 
-def parse(html: str, p: Product):
+def parse(html: str, p: Product, include: Sequence = None):
+    include = include or Product.__fields__.keys()
     sel = parsel.Selector(text=html)
-    parse_product_asin(p, selector=sel)
-    parse_parent_asin(p, selector=sel)
-    parse_weight(p, selector=sel)
-    parse_brand(p, selector=sel)
-    parse_price(p, selector=sel)
-    parse_in_stock(p, selector=sel)
-    parse_stock(p, selector=sel)
-    parse_ship_day(p, selector=sel)
-    parse_ship(p, selector=sel)
-    parse_sold(p, selector=sel)
-    parse_offers(p, selector=sel)
-    parse_delivery(p, selector=sel)
-    parse_material(p, selector=sel)
-    parse_description(p, selector=sel)
-    parse_title(p, selector=sel)
-    parse_size(p, selector=sel)
-    parse_color(p, selector=sel)
-    parse_variation(p, selector=sel)
-    parse_review_amount(p, selector=sel)
-    parse_review_star(p, selector=sel)
-    parse_rank(p, selector=sel)
+    "product_asin" in include and parse_product_asin(p, selector=sel)
+    "parent_asin" in include and parse_parent_asin(p, selector=sel)
+    "weight" in include and parse_weight(p, selector=sel)
+    "brand" in include and parse_brand(p, selector=sel)
+    "price" in include and parse_price(p, selector=sel)
+    "in_stock" in include and parse_in_stock(p, selector=sel)
+    "stock" in include and parse_stock(p, selector=sel)
+    "ship_day" in include and parse_ship_day(p, selector=sel)
+    "ship" in include and parse_ship(p, selector=sel)
+    "sold" in include and parse_sold(p, selector=sel)
+    "offers" in include and parse_offers(p, selector=sel)
+    "delivery" in include and parse_delivery(p, selector=sel)
+    "material" in include and parse_material(p, selector=sel)
+    "description" in include and parse_description(p, selector=sel)
+    "title" in include and parse_title(p, selector=sel)
+    "size" in include and parse_size(p, selector=sel)
+    "color" in include and parse_color(p, selector=sel)
+    "variation" in include and parse_variation(p, selector=sel)
+    "review_amount" in include and parse_review_amount(p, selector=sel)
+    "review_star" in include and parse_review_star(p, selector=sel)
+    "rank" in include and parse_rank(p, selector=sel)
 
 
 def parse_product_asin(p: Product, selector: parsel.Selector = None):
